==> 2025-11-13-11-48-27-dify-1.9.2.zip: dify-1.9.2/web/i18n/en-US/tools.ts <==
const translation = {
  title: 'Tools',
  createCustomTool: 'Create Custom Tool',
  customToolTip: 'Learn more about Dify custom tools',
  type: {
    all: 'All',
    builtIn: 'Tools',
    custom: 'Custom',
    workflow: 'Workflow',
  },
  contribute: {
    line1: 'I\'m interested in ',
    line2: 'contributing tools to Dify.',
    viewGuide: 'View the guide',
  },
  author: 'By',
  auth: {
    authorized: 'Authorized',
    setup: 'Set up authorization to use',
    setupModalTitle: 'Set Up Authorization',
    setupModalTitleDescription: 'After configuring credentials, all members within the workspace can use this tool when orchestrating applications.',
  },
  includeToolNum: '{{num}} {{action}} included',
  addTool: 'Add Tool',
  addToolModal: {
    type: 'type',
    category: 'category',
    add: 'add',
    added: 'added',
    manageInTools: 'Manage in Tools',
    custom: {
      title: 'No custom tool available',
      tip: 'Create a custom tool',
    },
    workflow: {
      title: 'No workflow tool available',
      tip: 'Publish workflows as tools in Studio',
    },
    mcp: {
      title: 'No MCP tool available',
      tip: 'Add an MCP server',
    },
    agent: {
      title: 'No agent strategy available',
    },
  },
  createTool: {
    title: 'Create Custom Tool',
    editAction: 'Configure',
    editTitle: 'Edit Custom Tool',
    name: 'Name',
    toolNamePlaceHolder: 'Enter the tool name',
    nameForToolCall: 'Tool call name',
    nameForToolCallPlaceHolder: 'Used for machine recognition, such as getCurrentWeather, list_pets',
    nameForToolCallTip: 'Only supports numbers, letters, and underscores.',
    description: 'Description',
    descriptionPlaceholder: 'Brief description of the tool\'s purpose, e.g., get the temperature for a specific location.',
    schema: 'Schema',
    schemaPlaceHolder: 'Enter your OpenAPI schema here',
    viewSchemaSpec: 'View the OpenAPI-Swagger Specification',
    importFromUrl: 'Import from URL',
    importFromUrlPlaceHolder: 'https://...',
    urlError: 'Please enter a valid URL',
    examples: 'Examples',
    exampleOptions: {
      json: 'Weather(JSON)',
      yaml: 'Pet Store(YAML)',
      blankTemplate: 'Blank Template',
    },
    availableTools: {
      title: 'Available Tools',
      name: 'Name',
      description: 'Description',
      method: 'Method',
      path: 'Path',
      action: 'Actions',
      test: 'Test',
    },
    authMethod: {
      title: 'Authorization method',
      type: 'Authorization type',
      keyTooltip: 'Http Header Key, You can leave it with "Authorization" if you have no idea what it is or set it to a custom value',
      queryParam: 'Query Parameter',
      queryParamTooltip: 'The name of the API key query parameter to pass, e.g. "key" in "https://example.com/test?key=API_KEY".',
      types: {
        none: 'None',
        api_key_header: 'Header',
        api_key_query: 'Query Param',
        apiKeyPlaceholder: 'HTTP header name for API Key',
        apiValuePlaceholder: 'Enter API Key',
        queryParamPlaceholder: 'Query parameter name for API Key',
      },
      key: 'Key',
      value: 'Value',
    },
    authHeaderPrefix: {
      title: 'Auth Type',
      types: {
        basic: 'Basic',
        bearer: 'Bearer',
        custom: 'Custom',
      },
    },
    privacyPolicy: 'Privacy policy',
    privacyPolicyPlaceholder: 'Please enter privacy policy',
    toolInput: {
      title: 'Tool Input',
      name: 'Name',
      required: 'Required',
      method: 'Method',
      methodSetting: 'Setting',
      methodSettingTip: 'User fills in the tool configuration',
      methodParameter: 'Parameter',
      methodParameterTip: 'LLM fills during inference',
      label: 'Tags',
      labelPlaceholder: 'Choose tags(optional)',
      description: 'Description',
      descriptionPlaceholder: 'Description of the parameter\'s meaning',
    },
    customDisclaimer: 'Custom disclaimer',
    customDisclaimerPlaceholder: 'Please enter custom disclaimer',
    confirmTitle: 'Confirm to save ?',
    confirmTip: 'Apps using this tool will be affected',
    deleteToolConfirmTitle: 'Delete this Tool?',
    deleteToolConfirmContent: 'Deleting the Tool is irreversible. Users will no longer be able to access your Tool.',
  },
  test: {
    title: 'Test',
    parametersValue: 'Parameters & Value',
    parameters: 'Parameters',
    value: 'Value',
    testResult: 'Test Results',
    testResultPlaceholder: 'Test result will show here',
  },
  thought: {
    using: 'Using',
    used: 'Used',
    requestTitle: 'Request',
    responseTitle: 'Response',
  },
  setBuiltInTools: {
    info: 'Info',
    setting: 'Setting',
    toolDescription: 'Tool description',
    parameters: 'parameters',
    string: 'string',
    number: 'number',
    file: 'file',
    required: 'Required',
    infoAndSetting: 'Info & Settings',
  },
  noCustomTool: {
    title: 'No custom tools!',
    content: 'Add and manage your custom tools here for building AI apps.',
    createTool: 'Create Tool',
  },
  noSearchRes: {
    title: 'Sorry, no results!',
    content: 'We couldn\'t find any tools that match your search.',
    reset: 'Reset Search',
  },
  builtInPromptTitle: 'Prompt',
  toolRemoved: 'Tool removed',
  notAuthorized: 'Not authorized',
  howToGet: 'How to get',
  openInStudio: 'Open in Studio',
  toolNameUsageTip: 'Tool call name for agent reasoning and prompting',
  copyToolName: 'Copy Name',
  noTools: 'No tools found',
  mcp: {
    create: {
      cardTitle: 'Add MCP Server (HTTP)',
      cardLink: 'Learn more about MCP server integration',
    },
    noConfigured: 'Unconfigured',
    updateTime: 'Updated',
    toolsCount: '{{count}} tools',
    noTools: 'No tools available',
    modal: {
      title: 'Add MCP Server (HTTP)',
      editTitle: 'Edit MCP Server (HTTP)',
      name: 'Name & Icon',
      namePlaceholder: 'Name your MCP server',
      serverUrl: 'Server URL',
      serverUrlPlaceholder: 'URL to server endpoint',
      serverUrlWarning: 'Updating the server address may disrupt applications that depend on this server',
      serverIdentifier: 'Server Identifier',
      serverIdentifierTip: 'Unique identifier for the MCP server within the workspace. Lowercase letters, numbers, underscores, and hyphens only. Up to 24 characters.',
      serverIdentifierPlaceholder: 'Unique identifier, e.g., my-mcp-server',
      serverIdentifierWarning: 'The server won\'t be recognized by existing apps after an ID change',
      headers: 'Headers',
      headersTip: 'Additional HTTP headers to send with MCP server requests',
      headerKey: 'Header Name',
      headerValue: 'Header Value',
      headerKeyPlaceholder: 'e.g., Authorization',
      headerValuePlaceholder: 'e.g., Bearer token123',
      addHeader: 'Add Header',
      noHeaders: 'No custom headers configured',
      maskedHeadersTip: 'Header values are masked for security. Changes will update the actual values.',
      cancel: 'Cancel',
      save: 'Save',
      confirm: 'Add & Authorize',
      timeout: 'Timeout',
      sseReadTimeout: 'SSE Read Timeout',
      timeoutPlaceholder: '30',
    },
    delete: 'Remove MCP Server',
    deleteConfirmTitle: 'Would you like to remove {{mcp}}?',
    operation: {
      edit: 'Edit',
      remove: 'Remove',
    },
    authorize: 'Authorize',
    authorizing: 'Authorizing...',
    authorizingRequired: 'Authorization is required',
    authorizeTip: 'After authorization, tools will be displayed here.',
    update: 'Update',
    updating: 'Updating',
    gettingTools: 'Getting Tools...',
    updateTools: 'Updating Tools...',
    toolsEmpty: 'Tools not loaded',
    getTools: 'Get tools',
    toolUpdateConfirmTitle: 'Update Tool List',
    toolUpdateConfirmContent: 'Updating the tool list may affect existing apps. Do you wish to proceed?',
    toolsNum: '{{count}} tools included',
    onlyTool: '1 tool included',
    identifier: 'Server Identifier (Click to Copy)',
    server: {
      title: 'MCP Server',
      url: 'Server URL',
      reGen: 'Do you want to regenerator server URL?',
      addDescription: 'Add description',
      edit: 'Edit description',
      modal: {
        addTitle: 'Add description to enable MCP server',
        editTitle: 'Edit description',
        description: 'Description',
        descriptionPlaceholder: 'Explain what this tool does and how it should be used by the LLM',
        parameters: 'Parameters',
        parametersTip: 'Add descriptions for each parameter to help the LLM understand their purpose and constraints.',
        parametersPlaceholder: 'Parameter purpose and constraints',
        confirm: 'Enable MCP Server',
      },
      publishTip: 'App not published. Please publish the app first.',
    },
    toolItem: {
      noDescription: 'No description',
      parameters: 'Parameters',
    },
  },
  allTools: 'All tools',
}

export default translation

==> 2025-11-24-10-54-20-dify-1.1.3.zip: dify-1.1.3/web/i18n/en-US/tools.ts <==
const translation = {
  title: 'Tools',
  createCustomTool: 'Create Custom Tool',
  customToolTip: 'Learn more about Dify custom tools',
  type: {
    all: 'All',
    builtIn: 'Tools',
    custom: 'Custom',
    workflow: 'Workflow',
  },
  contribute: {
    line1: 'I\'m interested in ',
    line2: 'contributing tools to Dify.',
    viewGuide: 'View the guide',
  },
  author: 'By',
  auth: {
    unauthorized: 'To Authorize',
    authorized: 'Authorized',
    setup: 'Set up authorization to use',
    setupModalTitle: 'Set Up Authorization',
    setupModalTitleDescription: 'After configuring credentials, all members within the workspace can use this tool when orchestrating applications.',
  },
  includeToolNum: '{{num}} {{action}} included',
  addTool: 'Add Tool',
  addToolModal: {
    type: 'type',
    category: 'category',
    add: 'add',
    added: 'added',
    manageInTools: 'Manage in Tools',
    emptyTitle: 'No workflow tool available',
    emptyTip: 'Go to "Workflow -> Publish as Tool"',
    emptyTitleCustom: 'No custom tool available',
    emptyTipCustom: 'Create a custom tool',
  },
  createTool: {
    title: 'Create Custom Tool',
    editAction: 'Configure',
    editTitle: 'Edit Custom Tool',
    name: 'Name',
    toolNamePlaceHolder: 'Enter the tool name',
    nameForToolCall: 'Tool call name',
    nameForToolCallPlaceHolder: 'Used for machine recognition, such as getCurrentWeather, list_pets',
    nameForToolCallTip: 'Only supports numbers, letters, and underscores.',
    description: 'Description',
    descriptionPlaceholder: 'Brief description of the tool\'s purpose, e.g., get the temperature for a specific location.',
    schema: 'Schema',
    schemaPlaceHolder: 'Enter your OpenAPI schema here',
    viewSchemaSpec: 'View the OpenAPI-Swagger Specification',
    importFromUrl: 'Import from URL',
    importFromUrlPlaceHolder: 'https://...',
    urlError: 'Please enter a valid URL',
    examples: 'Examples',
    exampleOptions: {
      json: 'Weather(JSON)',
      yaml: 'Pet Store(YAML)',
      blankTemplate: 'Blank Template',
    },
    availableTools: {
      title: 'Available Tools',
      name: 'Name',
      description: 'Description',
      method: 'Method',
      path: 'Path',
      action: 'Actions',
      test: 'Test',
    },
    authMethod: {
      title: 'Authorization method',
      type: 'Authorization type',
      keyTooltip: 'Http Header Key, You can leave it with "Authorization" if you have no idea what it is or set it to a custom value',
      types: {
        none: 'None',
        api_key: 'API Key',
        apiKeyPlaceholder: 'HTTP header name for API Key',
        apiValuePlaceholder: 'Enter API Key',
      },
      key: 'Key',
      value: 'Value',
    },
    authHeaderPrefix: {
      title: 'Auth Type',
      types: {
        basic: 'Basic',
        bearer: 'Bearer',
        custom: 'Custom',
      },
    },
    privacyPolicy: 'Privacy policy',
    privacyPolicyPlaceholder: 'Please enter privacy policy',
    toolInput: {
      title: 'Tool Input',
      name: 'Name',
      required: 'Required',
      method: 'Method',
      methodSetting: 'Setting',
      methodSettingTip: 'User fills in the tool configuration',
      methodParameter: 'Parameter',
      methodParameterTip: 'LLM fills during inference',
      label: 'Tags',
      labelPlaceholder: 'Choose tags(optional)',
      description: 'Description',
      descriptionPlaceholder: 'Description of the parameter\'s meaning',
    },
    customDisclaimer: 'Custom disclaimer',
    customDisclaimerPlaceholder: 'Please enter custom disclaimer',
    confirmTitle: 'Confirm to save ?',
    confirmTip: 'Apps using this tool will be affected',
    deleteToolConfirmTitle: 'Delete this Tool?',
    deleteToolConfirmContent: 'Deleting the Tool is irreversible. Users will no longer be able to access your Tool.',
  },
  test: {
    title: 'Test',
    parametersValue: 'Parameters & Value',
    parameters: 'Parameters',
    value: 'Value',
    testResult: 'Test Results',
    testResultPlaceholder: 'Test result will show here',
  },
  thought: {
    using: 'Using',
    used: 'Used',
    requestTitle: 'Request',
    responseTitle: 'Response',
  },
  setBuiltInTools: {
    info: 'Info',
    setting: 'Setting',
    toolDescription: 'Tool description',
    parameters: 'parameters',
    string: 'string',
    number: 'number',
    file: 'file',
    required: 'Required',
    infoAndSetting: 'Info & Settings',
  },
  noCustomTool: {
    title: 'No custom tools!',
    content: 'Add and manage your custom tools here for building AI apps.',
    createTool: 'Create Tool',
  },
  noSearchRes: {
    title: 'Sorry, no results!',
    content: 'We couldn\'t find any tools that match your search.',
    reset: 'Reset Search',
  },
  builtInPromptTitle: 'Prompt',
  toolRemoved: 'Tool removed',
  notAuthorized: 'Not authorized',
  howToGet: 'How to get',
  openInStudio: 'Open in Studio',
  toolNameUsageTip: 'Tool call name for agent reasoning and prompting',
  copyToolName: 'Copy Name',
  noTools: 'No tools found',
}

export default translation
